Często zadawane pytania
=======================

Przy eksporcie PBN, mogę wybrać datę "data ostatniej zmiany" lub "data ostatniej zmiany dla PBN", jaka jest między nimi różnica?
--------------------------------------------------------------------------------------------------------------------------------


"Data ostatniej zmiany" to data ostatniej zmiany rekordu. Data w tymu polu
aktualizowana jest automatycznie w chwili zapisu rekordu w module "Redagowanie".

"Data ostatniej zmiany dla PBN" to pole, które wskazuje na datę ostatniej
zmiany rekordu w sytuacji, gdyby zmieniły się jakiekolwiek informacje mające
wpływ na zapis rekordu w systemie PBN. Użycie tego pola zostało podyktowane
względami praktycznymi. Pole to nie zostanie zaktualizowane, jeżeli zostają
zmienione informacje w polu "Adnotacje" (jest to pole do użytku wewnętrznego
dla redaktorów systemu bazodanowego), w polach punktowych oraz polach
punktowych dla komisji centralnej. W przeciwnym wypadku, gdy zmienione zostały
jakiekolwiek inne pola, data w polu "Data ostatniej zmiany dla PBN" będzie
zaktualizowana. 
